/*
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 .
 This package is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 .
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <http://www.gnu.org/licenses/>.
 .
 On Debian systems, the complete text of the GNU General
 Public License version 3 can be found in "/usr/share/common-licenses/GPL-3".
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <poll.h>
#include <ncurses.h>
#include <time.h>

#define NB_CHARS 5
#define MAX_TEST_TIME (1000 * NB_CHARS)

/* Uncomment the following to print pressed keys */
/* #define DEBUG_CHARS 1 */

const char *char_seq[NB_CHARS] = 
{ 
	"a",
	"b",
	"c",
	"d",
	"e"
};

static char* ret_file;

void write_and_exit(int exit_code)
{
	FILE *file;

	file = fopen(ret_file, "w");
	fprintf(file, "%d", exit_code);
	fclose(file);
	
	/* don't forget to reset ncurses tty */
	endwin ();

	/* and we exit gracefully, as the test is over */
	exit(0);
}


int main(int argc, char* argv[])
{
        struct pollfd pfd;
        int c, index = 0;
	FILE retFile;

	if (argc <= 1)
		exit(1);
	else
		ret_file = argv[1];

	/* get current time  */
	clock_t start;
	clock_t now;
	int elapsed_time;
	start = clock();

	/* init ncurses */
        initscr();
        cbreak();
        noecho();
        keypad(stdscr, TRUE);
        nodelay(stdscr, TRUE);
        pfd.fd = fileno(stdin);
        pfd.events = POLLIN;

        for (;;) {
		c = getch();
		if (c != ERR) {
			if (strcmp(keyname(c), char_seq[index++])) {
				/* we received the wrong key, let's FAIL */
				write_and_exit(1);
			} else {
#ifdef DEBUG_CHARS
                        	printw("key: %s\n", keyname(c));
#endif
				/* we received the right key, let's PASS */
				// if we've reached the end of char_seq
				if (index >= NB_CHARS) {
					endwin();
					write_and_exit(0);
				}
			}
		}	
                refresh();

		/* Get time in miliseconds and exit if we've been waiting
		   too long  */
		now = clock();
		elapsed_time = (double)(now - start) / 
			(CLOCKS_PER_SEC / 1000.0);
		if (elapsed_time > MAX_TEST_TIME)
			break;
        }
	/* we've waited too long for the expected keyevents, FAIL and exit ! */
	write_and_exit(1);

	/* we should never exit here*/
	return 1;
} 
