#!/usr/bin/env python
# -*- coding: utf-8 -*-

import gobject
import sys
from glib import GError

import pygst
pygst.require("0.10")
import gst
import json

import os
import sys

class DecodeTest(object):

    def __init__ (self, path, filename, has_video):
        self.loop = gobject.MainLoop()
        self.filename = filename
        self.pipeline = gst.element_factory_make("playbin2")
        self.pipeline.get_bus().add_watch(self.async_handler)

        self.pipeline.set_property ("uri",
            "file://" + os.path.join(path, filename ))

        self.asink = gst.element_factory_make ("fakesink", "asink")
        self.asink.set_property("enable-last-buffer", True)
        self.pipeline.set_property ("audio-sink", self.asink)

        if (has_video):
            self.vsink = gst.element_factory_make ("fakesink", "vsink")
            self.vsink.set_property("enable-last-buffer", True)
            self.pipeline.set_property ("video-sink", self.vsink)
        else:
            self.vsink = None

        self.has_video = has_video
        self.failed = False

    def async_handler (self, bus, message):
        if message.type == gst.MESSAGE_ERROR:
            print "%s: FAILED (%s)\n" % (self.filename, message.parse_error()[1])
            self.failed = True
            self.loop.quit()
        elif message.type == gst.MESSAGE_EOS:
            self.loop.quit()
        return True

    def run_test (self):
        self.pipeline.set_state (gst.STATE_PLAYING)
        self.loop.run()
        if self.failed:
            return False

        print "%s - audio: %s" % (self.filename,
            self.asink.get_property ("last-buffer") and "PASSED" or "FAILED")
        if self.has_video:
            print "%s - video: %s" % (self.filename,
                self.vsink.get_property ("last-buffer") and "PASSED" or "FAILED")
        return not self.failed


if __name__ == '__main__':
    media = json.loads(file(os.path.join (sys.argv[1], "media.js")).read())

    for x in media["files"]:
        DecodeTest (sys.argv[1], x["name"], x["video"]).run_test()
